@@ -6,7 +6,9 @@
 from __future__ import annotations
 
 import argparse
+from typing import Generator
 import rabbitizer
+import sys
 
 from .. import common
 
@@ -15,7 +17,7 @@ def getArgsParser() -> argparse.ArgumentParser:
     description = "CLI tool to disassemble multiples instructions passed as argument"
     parser = argparse.ArgumentParser(description=description)
 
-    parser.add_argument("input", help="Hex words to be disassembled. Leading '0x' must be omitted")
+    parser.add_argument("input", help="Hex words to be disassembled. Leading '0x' must be omitted", nargs='?')
 
     parser.add_argument("--endian", help="Set the endianness of input files. Defaults to 'big'", choices=["big", "little", "middle"], default="big")
     parser.add_argument("--category", help="The instruction category to use when disassembling every passed instruction. Defaults to 'cpu'", choices=["cpu", "rsp", "r5900"])
@@ -34,22 +36,35 @@ def getInstrCategoryFromStr(category: str) -> rabbitizer.Enum:
 
     return rabbitizer.InstrCategory.CPU
 
-def getWordListFromStr(inputStr: str) -> list[int]:
-    wordList: list[int] = []
+def getWordListFromStrList(inputlist: list|None) -> Generator[int, None, None]:
+    if inputlist is None:
+        return
 
     wordStr = ""
-    for character in inputStr:
-        if character not in "0123456789abcdefABCDEF":
-            continue
-        wordStr += character
-        if len(wordStr) == 8:
-            wordList.append(int(wordStr, 16))
-            wordStr = ""
+    for inputStr in inputlist:
+        for character in inputStr:
+            if character not in "0123456789abcdefABCDEF":
+                continue
+            wordStr += character
+            if len(wordStr) == 8:
+                yield int(wordStr, 16)
+                wordStr = ""
 
     if len(wordStr) > 0:
-        wordList.append(int(wordStr, 16))
+        yield int(wordStr, 16)
 
-    return wordList
+def getWordListFromStdin():
+    if sys.stdin.isatty():
+        return
+
+    lines = ""
+    try:
+        for line in sys.stdin:
+            lines += line
+    except KeyboardInterrupt:
+        pass
+    for word in getWordListFromStrList(lines.split(" ")):
+        yield word
 
 
 def disasmdisMain():
@@ -59,6 +74,10 @@ def disasmdisMain():
 
     category = getInstrCategoryFromStr(args.category)
 
-    for word in getWordListFromStr(args.input):
+    for word in getWordListFromStdin():
+        instr = rabbitizer.Instruction(word, category=category)
+        print(instr.disassemble())
+
+    for word in getWordListFromStrList(args.input):
         instr = rabbitizer.Instruction(word, category=category)
         print(instr.disassemble())
